@@ -59,7 +59,7 @@ use base qw( Exporter DynaLoader );
 sub dl_load_flags { 0x01 } # global option
 
 BEGIN {
-  $VERSION = '1.01';
+  $VERSION = '1.02';
   bootstrap Net::Silk $VERSION;
 }
 
@@ -94,12 +94,14 @@ use constant SILK_BAG_ITER_CLASS        => 'Net::Silk::Bag::iter_xs';
 use constant SILK_PMAP_ITER_CLASS       => 'Net::Silk::Pmap::iter_xs';
 use constant SILK_SITE_REPO_ITER_CLASS  => 'Net::Silk::Site::iter_xs';
 
+use constant SILK_SITE_CLASS    => 'Net::Silk::Site';
 use constant SILK_FILE_CLASS    => 'Net::Silk::File';
 use constant SILK_FILE_IO_CLASS => 'Net::Silk::File::io_xs';
 
-use Math::BigInt try => 'GMP';
 use Math::Int64;
 use Math::Int64::die_on_overflow;
+use Math::Int128;
+use Math::Int128::die_on_overflow;
 
 # note: SILK_IPV6_ENABLED defined in Silk.xs/BOOT
 
@@ -139,10 +141,10 @@ BEGIN {
 
     SILK_PROTOPORT_CLASS
 
+    SILK_SITE_CLASS
     SILK_FILE_CLASS
     SILK_FILE_IO_CLASS
 
-    hex_cast
     compression_methods
     timezone_support
 
@@ -163,23 +165,6 @@ BEGIN {
 
 ###
 
-my $nan = Math::BigInt->bnan;
-
-sub hex_cast {
-  if (ref $_[0]) {
-    return UNIVERSAL::isa($_[0], "Math::BigInt") ? "$_[0]" : $_[0];
-  }
-  return $_[0] if looks_like_number($_[0]);
-  if ($_[0] =~ /^0x/ && $_[0] =~ /^0x[0-9a-fA-F_]*$/) {
-    my $n;
-    eval { $n = Math::Int64::hex_to_uint64($_[0]) };
-    return $n unless $@;
-    $n = Math::BigInt->from_hex($_[0]);
-    return $n == $nan ? $_[0] : "$n";
-  }
-  $_[0];
-}
-
 sub compression_methods {
   my @cmethods = ["none"];
   push(@cmethods, "zlib")  if SILK_ZLIB_ENABLED;
